@@ -511,7 +511,7 @@ scatter.glPca <- function(x, xax=1, yax=2, posi="bottomleft", bg="white", ratio=
                           grid = TRUE, addaxes = TRUE, origin = c(0,0), include.origin = TRUE,
                           sub = "", csub = 1, possub = "bottomleft", cgrid = 1,
                           pixmap = NULL, contour = NULL, area = NULL, ...){
-    if(!require(ade4, quiet=TRUE)) stop("ade4 library is required.")
+    if(!require(ade4, quietly=TRUE)) stop("ade4 library is required.")
 
 
     ## set par
